@@ -1,5 +1,5 @@
 import dataclasses
-from typing import Optional, Dict
+from typing import Optional, Dict, Union
 
 MESSAGE_TYPE_ONESHOT = 0
 MESSAGE_TYPE_REQUEST = 1
@@ -7,6 +7,8 @@ MESSAGE_TYPE_RESPONSE = 2
 MESSAGE_TYPE_ERROR = 3
 MESSAGE_TYPE_BROADCAST = 4
 MESSAGE_TYPE = int
+RESPONSE_TYPES = Union['ErrorResponse', 'MessageResponse', 'NotificationResponse']
+
 
 
 @dataclasses.dataclass
@@ -32,8 +34,8 @@ class ErrorResponse:
 
 
 @dataclasses.dataclass
-class EventResponse:
+class NotificationResponse:
     cmd: str
     data: str
-    type: MESSAGE_TYPE = 3
+    type: MESSAGE_TYPE = MESSAGE_TYPE_ONESHOT
 
